@@ -505,6 +505,12 @@ func TestNoParameterEvaluation(test *testing.T) {
 			Input:    "!(1 in (1, 2, 3))",
 			Expected: false,
 		},
+		EvaluationTest{
+
+			Name:     "Single Element Array membership literal",
+			Input:    "1 in (1)",
+			Expected: true,
+		},
 		EvaluationTest{
 
 			Name:     "Logical operator reordering (#30)",
